@@ -1,17 +1,32 @@
 /*
     This file is part of the Okteta Designer plugin, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2009 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "fillerbytearraymodel.hpp"
+#include "fillerbytearraymodel.h"
 
 // Okteta core
-#include <Okteta/PieceTableByteArrayModel>
+#include <okteta/piecetablebytearraymodel.h>
 
-static constexpr char fillerData[] =
+
+static const char fillerData[] =
     "This is some filler data for the Okteta byte array widgets:"
     "\x00\x01\x02\x03\x04\x05\x06\x07\x08\x09\x0A\x0B\x0C\x0D\x0E\x0F"
     "\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1A\x1B\x1C\x1D\x1E\x1F"
@@ -30,12 +45,13 @@ static constexpr char fillerData[] =
     "\xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF"
     "\xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF";
 
-static constexpr std::size_t fillerDataSize = sizeof(fillerData) / sizeof(fillerData[0]);
+static const int fillerDataSize = sizeof(fillerData) / sizeof(fillerData[0]);
 
-Okteta::AbstractByteArrayModel* createFillerByteArrayModel(QObject* parent)
+
+Okteta::AbstractByteArrayModel* createFillerByteArrayModel( QObject* parent )
 {
     Okteta::PieceTableByteArrayModel* fillerByteArrayModel =
-        new Okteta::PieceTableByteArrayModel(QByteArray::fromRawData(fillerData, fillerDataSize), parent);
+        new Okteta::PieceTableByteArrayModel( QByteArray::fromRawData(fillerData, fillerDataSize), parent );
 
     return fillerByteArrayModel;
 }
