@@ -18,11 +18,11 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <QtTest/QtTest>
+#include <QTest>
 
 #include <limits>
 
-#include <bytearraymodel.h>
+#include <okteta/bytearraymodel.h>
 #include "view/structures/datatypes/topleveldatainformation.h"
 #include "view/structures/datatypes/structuredatainformation.h"
 #include "view/structures/datatypes/primitive/primitivetemplateinfo.h"
