@@ -24,9 +24,9 @@
 #define BOOKMARKSTOOLVIEW_H
 
 // lib
-#include "oktetakastencontrollers_export.h"
+#include <kasten/okteta/oktetakastencontrollers_export.h>
 // Kasten gui
-#include <abstracttoolview.h>
+#include <kasten/abstracttoolview.h>
 
 
 namespace Kasten
