@@ -24,7 +24,7 @@
 #define SELECTRANGEVIEW_H
 
 // Kasten gui
-#include <abstracttoolwidget.h>
+#include <kasten/abstracttoolwidget.h>
 
 namespace Okteta {
 class AddressComboBox;
