@@ -22,4 +22,8 @@
 
 #include "oktetakastengui.h"
 
+#if QT_VERSION >= 0x050500
+Q_LOGGING_CATEGORY(LOG_KASTEN_OKTETA_GUI, "kasten.okteta.gui", QtInfoMsg)
+#else
 Q_LOGGING_CATEGORY(LOG_KASTEN_OKTETA_GUI, "kasten.okteta.gui")
+#endif
