@@ -22,9 +22,11 @@
 
 #include "abstractcontroller.h"
 
-namespace Kasten {
 
-void AbstractController::setTargetModel(AbstractModel* model)
+namespace Kasten
+{
+
+void AbstractController::setTargetModel( AbstractModel* model )
 {
     Q_UNUSED(model)
 }
